use crate::app_config::AppConfig;
use crate::constants::StaticConstraints;
use actix_web::HttpResponse;

pub async fn secure_home() -> HttpResponse {
    HttpResponse::Ok()
        .content_type("text/plain")
        .body("SolarEnergy secure central backend")
}

#[derive(serde::Serialize)]
struct ServerConfig {
    auth_disabled: bool,
    constraints: StaticConstraints,
}

impl Default for ServerConfig {
    fn default() -> Self {
        Self {
            auth_disabled: AppConfig::get().unsecure_disable_login,
            constraints: Default::default(),
        }
    }
}

pub async fn config() -> HttpResponse {
    HttpResponse::Ok().json(ServerConfig::default())
}
